Index: content/browser/ssl/ssl_manager_unittest.cc |
diff --git a/content/browser/ssl/ssl_manager_unittest.cc b/content/browser/ssl/ssl_manager_unittest.cc |
index 7beadeb2c4bd0ae11bf6dd48cd16adc526e9c3be..8468bb14d12588aa99cbfdc357080608265f9252 100644 |
--- a/content/browser/ssl/ssl_manager_unittest.cc |
+++ b/content/browser/ssl/ssl_manager_unittest.cc |
@@ -28,7 +28,7 @@ |
const SSLStatus& last_ssl_state() { return last_ssl_state_; } |
// WebContentsDelegate: |
- void VisibleSecurityStateChanged(WebContents* source) override { |
+ void VisibleSSLStateChanged(WebContents* source) override { |
NavigationEntry* entry = source->GetController().GetVisibleEntry(); |
EXPECT_TRUE(entry); |
last_ssl_state_ = entry->GetSSL(); |
@@ -48,7 +48,7 @@ |
DISALLOW_COPY_AND_ASSIGN(SSLManagerTest); |
}; |
// Tests that VisibleSecurityStateChanged() is called when a password input |
// is shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) { |
TestWebContentsDelegate delegate; |
@@ -64,7 +64,7 @@ |
SSLStatus::DISPLAYED_PASSWORD_FIELD_ON_HTTP); |
} |
// Tests that VisibleSecurityStateChanged() is called when a credit card input |
// is shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) { |
TestWebContentsDelegate delegate; |
@@ -80,7 +80,7 @@ |
SSLStatus::DISPLAYED_CREDIT_CARD_FIELD_ON_HTTP); |
} |
// Tests that VisibleSecurityStateChanged() is called when password and |
// credit card inputs are shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnPasswordAndHttpCreditCard) { |
TestWebContentsDelegate delegate; |
@@ -48,7 +48,7 @@ |
DISALLOW_COPY_AND_ASSIGN(SSLManagerTest); |
}; |
-// Tests that VisibleSecurityStateChanged() is called when a password input |
+// Tests that VisibleSSLStateChanged() is called when a password input |
// is shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpPassword) { |
@@ -64,7 +64,7 @@ |
SSLStatus::DISPLAYED_PASSWORD_FIELD_ON_HTTP); |
} |
-// Tests that VisibleSecurityStateChanged() is called when a credit card input |
+// Tests that VisibleSSLStateChanged() is called when a credit card input |
// is shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnHttpCreditCard) { |
@@ -80,7 +80,7 @@ |
SSLStatus::DISPLAYED_CREDIT_CARD_FIELD_ON_HTTP); |
} |
-// Tests that VisibleSecurityStateChanged() is called when password and |
+// Tests that VisibleSSLStateChanged() is called when password and |
// credit card inputs are shown on an HTTP page. |
TEST_F(SSLManagerTest, NotifyVisibleSSLStateChangeOnPasswordAndHttpCreditCard) { |